@@ -20,7 +20,7 @@ class prime_cache(ContextDecorator):
 
         if not data:
             try:
-                resp = requests.get(self.data_source, timeout=self.timeoout)
+                resp = requests.get(self.data_source, timeout=self.timeout)
 
                 if resp.status_code == requests.codes.ok:
                     data = json.loads(resp.text)
